@@ -5,56 +5,37 @@
  ** fixbuf IPFIX Implementation Private Interface
  **
  ** ------------------------------------------------------------------------
- ** Copyright (C) 2006-2014 Carnegie Mellon University. All Rights Reserved.
+ ** Copyright (C) 2006-2018 Carnegie Mellon University. All Rights Reserved.
  ** ------------------------------------------------------------------------
  ** Authors: Brian Trammell
  ** ------------------------------------------------------------------------
- ** @OPENSOURCE_HEADER_START@
- ** Use of the libfixbuf system and related source code is subject to the terms
- ** of the following licenses:
+ ** @OPENSOURCE_LICENSE_START@
+ ** libfixbuf 2.0
  **
- ** GNU Lesser GPL (LGPL) Rights pursuant to Version 2.1, February 1999
- ** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+ ** Copyright 2018 Carnegie Mellon University. All Rights Reserved.
  **
- ** NO WARRANTY
+ ** NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE
+ ** ENGINEERING INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS"
+ ** BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY KIND,
+ ** EITHER EXPRESSED OR IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT
+ ** LIMITED TO, WARRANTY OF FITNESS FOR PURPOSE OR MERCHANTABILITY,
+ ** EXCLUSIVITY, OR RESULTS OBTAINED FROM USE OF THE
+ ** MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT MAKE ANY WARRANTY OF
+ ** ANY KIND WITH RESPECT TO FREEDOM FROM PATENT, TRADEMARK, OR
+ ** COPYRIGHT INFRINGEMENT.
  **
- ** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
- ** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
- ** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
- ** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
- ** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
- ** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
- ** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
- ** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
- ** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
- ** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
- ** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
- ** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
- ** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
- ** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
- ** DELIVERABLES UNDER THIS LICENSE.
+ ** Released under a GNU-Lesser GPL 3.0-style license, please see
+ ** LICENSE.txt or contact permission@sei.cmu.edu for full terms.
  **
- ** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
- ** Mellon University, its trustees, officers, employees, and agents from
- ** all claims or demands made against them (and any related losses,
- ** expenses, or attorney's fees) arising out of, or relating to Licensee's
- ** and/or its sub licensees' negligent use or willful misuse of or
- ** negligent conduct or willful misconduct regarding the Software,
- ** facilities, or other rights or assistance granted by Carnegie Mellon
- ** University under this License, including, but not limited to, any
- ** claims of product liability, personal injury, death, damage to
- ** property, or violation of any laws or regulations.
+ ** [DISTRIBUTION STATEMENT A] This material has been approved for
+ ** public release and unlimited distribution.  Please see Copyright
+ ** notice for non-US Government use and distribution.
  **
- ** Carnegie Mellon University Software Engineering Institute authored
- ** documents are sponsored by the U.S. Department of Defense under
- ** Contract FA8721-05-C-0003. Carnegie Mellon University retains
- ** copyrights in all material produced under this contract. The U.S.
- ** Government retains a non-exclusive, royalty-free license to publish or
- ** reproduce these documents, or allow others to do so, for U.S.
- ** Government purposes only pursuant to the copyright license under the
- ** contract clause at 252.227.7013.
+ ** Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent
+ ** and Trademark Office by Carnegie Mellon University.
  **
- ** @OPENSOURCE_HEADER_END@
+ ** DM18-0325
+ ** @OPENSOURCE_LICENSE_END@
  ** ------------------------------------------------------------------------
  */
 
@@ -67,7 +48,6 @@
 #include <pthread.h>
 #endif
 
-#ident "$Id$"
 
 /**
  * @file
@@ -82,9 +62,6 @@
 
 /** define the bit in ID's that marks the Enterprise ID's */
 #define IPFIX_ENTERPRISE_BIT    0x8000
-/** This is the Private Enterprise Number defined in the
-    IPFIX standard, see RFC 5102, for reverse flow datum */
-#define IPFIX_REVERSE_PEN       29305
 
 /** definition of the max-size of an fbuf_t buffer, or the
     default/only size */
@@ -92,14 +69,23 @@
 
 #if HAVE_SPREAD
 
+/**
+ * sp_groupname_t
+ */
 typedef struct sp_groupname_st
 {
     char    name[MAX_GROUP_NAME];
 } sp_groupname_t;
 
+/** maximum number of groups supported */
 #define FB_SPREAD_NUM_GROUPS    16
+
+/** maximum size of expected message */
 #define FB_SPREAD_MTU           8192
 
+/**
+ * fbSpreadSpec_t
+ */
 typedef struct fbSpreadSpec_st {
     /** pointer to the session, this MUST be set to a valid session before
     *   the spec is passed to fbExporterAllocSpread. */
@@ -107,7 +93,8 @@ typedef struct fbSpreadSpec_st {
     /** pointer to the daemon host address, in Spread format.  Must be set
     *   before the spec is passed to fbExporterAllocSpread */
     char *          daemon;
-    /** pointer to array of group names, must have at least one, and must be null term array */
+    /** pointer to array of group names, must have at least one, and
+     * must be null term array */
     sp_groupname_t  *groups;
     /** number of groups in groups */
     int             num_groups;
@@ -176,6 +163,32 @@ typedef struct fbUDPConnSpec_st {
 } fbUDPConnSpec_t;
 
 
+#ifdef DEFINE_TEMPLATE_METADATA_SPEC
+/* Template metadata template */
+static fbInfoElementSpec_t template_metadata_spec[] = {
+    /* {"templateInformationElementList",         FB_IE_VARLEN, 0 }, */
+    {"templateName",                           FB_IE_VARLEN, 0 },
+    {"templateDescription",                    FB_IE_VARLEN, 0 },
+    {"templateId",                             2, 0 },
+    FB_IESPEC_NULL
+};
+#endif
+
+/**
+ * Template metadata options record structure
+ *
+ */
+typedef struct fbTemplateOptRec_st {
+    /** List of PEN, IE num pairs */
+    /* fbSubTemplateList_t info_element_list; */
+    /** Template name */
+    fbVarfield_t   template_name;
+    /** Template description (optional) */
+    fbVarfield_t   template_description;
+    /** Template ID */
+    uint16_t       template_id;
+} fbTemplateOptRec_t;
+
 /**
  * An IPFIX template or options template structure. Part of the private
  * interface. Applications should use the fbTemplate calls defined in public.h
@@ -201,7 +214,7 @@ struct fbTemplate_st {
      */
     uint16_t            ie_len;
     /**
-     * Total length required to store this template in a data structure.
+     * Total length required to store this template in memory.
      * Uses sizeof(fbVarfield_t), sizeof(fbBasicList_t), etc instead of 0
      * as done with ie_len
      */
@@ -217,19 +230,26 @@ struct fbTemplate_st {
     fbInfoElement_t     **ie_ary;
     /** Map of information element to index in ie_ary. */
     GHashTable          *indices;
-        /** Field offset cache. For internal use by the transcoder. */
+    /** Field offset cache. For internal use by the transcoder. */
     uint16_t            *off_cache;
     /** TRUE if this template has been activated (is no longer mutable) */
     gboolean            active;
+    /**
+     * TRUE if any field was created using an fbInfoElementSpec_t
+     * with a defaulted length
+     */
+    gboolean            default_length;
+
+    fbTemplateOptRec_t  *metadata_rec;
     /**
      * Template context. Created and owned by the application
-     * when the listener calls the fbTemplateCtxCallback_fn.
+     * when the listener calls the fbNewTemplateCallback_fn.
      */
     void                *tmpl_ctx;
     /**
      * Callback to free the ctx pointer when template is freed
      */
-    fbTemplateCtxFree2_fn ctx_free;
+    fbTemplateCtxFree_fn ctx_free;
     /**
      * The application's Context pointer for the ctx_free function.
      */
@@ -296,6 +316,20 @@ void         fBufSetSession(
     fBuf_t          *fbuf,
     fbSession_t     *session);
 
+/**
+ * fBufGetExportTemplate
+ *
+ */
+uint16_t        fBufGetExportTemplate(
+    fBuf_t          *fbuf);
+
+
+/**
+ * fBufGetInternalTemplate
+ *
+ */
+uint16_t       fBufGetInternalTemplate(
+    fBuf_t         *fbuf);
 
 /**
  * fbInfoElementHash
@@ -431,26 +465,17 @@ void                fbTemplateDebug(
  * @param session
  * @return the callback function variable in the session
  */
-fbNewTemplateCallback_fn fbSessionTemplateCallback(
+fbNewTemplateCallback_fn fbSessionNewTemplateCallback(
     fbSession_t     *session);
 
 /**
- * Return the ctx callback function for a given session
- *
- * @param session
- * @return the Context callback function added to the session
- */
-fbTemplateCtxCallback2_fn fbSessionTemplateCtxCallback(
-    fbSession_t *session);
-
-/**
- * Return the ctx callback function's application context for a given
+ * Return the callback function's application context for a given
  * session
  *
  * @param session
  * @return the Application context pointer added to the session
  */
-void *fbSessionTemplateCtxCallbackAppCtx(
+void *fbSessionNewTemplateCallbackAppCtx(
     fbSession_t *session);
 
 /**
@@ -544,22 +569,49 @@ unsigned int fbSessionGetGroupOffset(
 /**
  * fbSessionGetGroup
  *
+ * @param session
+ *
  */
 unsigned int       fbSessionGetGroup(
     fbSession_t      *session);
 #endif
 
+/**
+ * fbSessionClearIntTmplTableFlag
+ *
+ * @param session
+ *
+ */
 void fbSessionClearIntTmplTableFlag(
     fbSession_t        *session);
 
+/**
+ * fbSessionClearExtTmplTableFlag
+ *
+ * @param session
+ *
+ */
 void fbSessionClearExtTmplTableFlag(
     fbSession_t        *session);
 
+/**
+ * fbSessionIntTmplTableFlagIsSet
+ *
+ * @param session
+ *
+ */
 int fbSessionIntTmplTableFlagIsSet(
     fbSession_t        *session);
 
+/**
+ * fbSessionExtTmplTableFlagIsSet
+ *
+ * @param session
+ *
+ */
 int fbSessionExtTmplTableFlagIsSet(
     fbSession_t        *session);
+
 /**
  * fbConnSpecLookupAI
  *
@@ -644,7 +696,7 @@ const char * fbConnSpreadError(
  *
  * @param exporter
  * @param groups
- * @param number of groups in above group list
+ * @param num_groups of groups in above group list
  *
  */
 
@@ -659,7 +711,7 @@ void fbExporterSetGroupsToSend(
  *
  * @param exporter
  * @param groups
- * @param number of groups in above group list
+ * @param num_groups of groups in above group list
  * @return TRUE if group is in subscribed group list
  *
  */
