@@ -5,56 +5,37 @@
  ** IPFIX Collecting Process single transport session implementation
  **
  ** ------------------------------------------------------------------------
- ** Copyright (C) 2006-2014 Carnegie Mellon University. All Rights Reserved.
+ ** Copyright (C) 2006-2018 Carnegie Mellon University. All Rights Reserved.
  ** ------------------------------------------------------------------------
  ** Authors: Brian Trammell
  ** ------------------------------------------------------------------------
- ** @OPENSOURCE_HEADER_START@
- ** Use of the libfixbuf system and related source code is subject to the terms
- ** of the following licenses:
+ ** @OPENSOURCE_LICENSE_START@
+ ** libfixbuf 2.0
  **
- ** GNU Lesser GPL (LGPL) Rights pursuant to Version 2.1, February 1999
- ** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+ ** Copyright 2018 Carnegie Mellon University. All Rights Reserved.
  **
- ** NO WARRANTY
+ ** NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE
+ ** ENGINEERING INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS"
+ ** BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY KIND,
+ ** EITHER EXPRESSED OR IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT
+ ** LIMITED TO, WARRANTY OF FITNESS FOR PURPOSE OR MERCHANTABILITY,
+ ** EXCLUSIVITY, OR RESULTS OBTAINED FROM USE OF THE
+ ** MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT MAKE ANY WARRANTY OF
+ ** ANY KIND WITH RESPECT TO FREEDOM FROM PATENT, TRADEMARK, OR
+ ** COPYRIGHT INFRINGEMENT.
  **
- ** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
- ** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
- ** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
- ** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
- ** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
- ** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
- ** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
- ** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
- ** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
- ** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
- ** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
- ** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
- ** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
- ** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
- ** DELIVERABLES UNDER THIS LICENSE.
+ ** Released under a GNU-Lesser GPL 3.0-style license, please see
+ ** LICENSE.txt or contact permission@sei.cmu.edu for full terms.
  **
- ** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
- ** Mellon University, its trustees, officers, employees, and agents from
- ** all claims or demands made against them (and any related losses,
- ** expenses, or attorney's fees) arising out of, or relating to Licensee's
- ** and/or its sub licensees' negligent use or willful misuse of or
- ** negligent conduct or willful misconduct regarding the Software,
- ** facilities, or other rights or assistance granted by Carnegie Mellon
- ** University under this License, including, but not limited to, any
- ** claims of product liability, personal injury, death, damage to
- ** property, or violation of any laws or regulations.
+ ** [DISTRIBUTION STATEMENT A] This material has been approved for
+ ** public release and unlimited distribution.  Please see Copyright
+ ** notice for non-US Government use and distribution.
  **
- ** Carnegie Mellon University Software Engineering Institute authored
- ** documents are sponsored by the U.S. Department of Defense under
- ** Contract FA8721-05-C-0003. Carnegie Mellon University retains
- ** copyrights in all material produced under this contract. The U.S.
- ** Government retains a non-exclusive, royalty-free license to publish or
- ** reproduce these documents, or allow others to do so, for U.S.
- ** Government purposes only pursuant to the copyright license under the
- ** contract clause at 252.227.7013.
+ ** Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent
+ ** and Trademark Office by Carnegie Mellon University.
  **
- ** @OPENSOURCE_HEADER_END@
+ ** DM18-0325
+ ** @OPENSOURCE_LICENSE_END@
  ** ------------------------------------------------------------------------
  */
 
@@ -64,7 +45,6 @@
 
 #include "fbcollector.h"
 
-#ident "$Id$"
 
 /*#################################################
  *
@@ -900,10 +880,7 @@ static gboolean fbCollectorReadUDP(
                        (struct sockaddr *)&peer, &peerlen);
 
 
-    if (peer.so.sa_family == AF_INET && !collector->stream_by_port) {
-        peer.ip4.sin_port = 0;
-    } else if (peer.so.sa_family == AF_INET6) {
-        if (!collector->stream_by_port) peer.ip6.sin6_port = 0;
+    if (peer.so.sa_family == AF_INET6) {
         peer.ip6.sin6_flowinfo = 0;
         peer.ip6.sin6_scope_id = 0;
     }
@@ -914,11 +891,11 @@ static gboolean fbCollectorReadUDP(
 
     if (msgSize > 0) {
         *msglen = msgSize;
-        /** Fixed this to do the right thing.  We now map ip addresses
-         * and observation domains to sessions.  If accept-only is set
-         * on the collector, we'll only return TRUE if the ips match.
-         * We will return NL_READ if FALSE, and the app using fixbuf
-         * should ignore error codes = NL_READ.**/
+        /** Fixed this to do the right thing.  We now map ip
+         * addresses/port and observation domains to sessions.  If
+         * accept-only is set on the collector, we'll only return TRUE
+         * if the ip/ports match.  We will return NL_READ if FALSE, and the
+         * app using fixbuf should ignore error codes = NL_READ.**/
 
         /* this will only veto if we set accept from explicitly*/
         if (!fbCollectorVerifyUDPPeer(collector, &(peer.so), peerlen, err)) {
@@ -1404,7 +1381,7 @@ static gboolean fbCollectorSpreadOpen(
         return FALSE;
     }
 
-    // mark it active here, fbCollectorFree() will need to disconnect
+    /* mark it active here, fbCollectorFree() will need to disconnect */
     collector->active = TRUE;
 
     for (i = 0; i < spread->num_groups; ++i)
@@ -1420,8 +1397,8 @@ static gboolean fbCollectorSpreadOpen(
     }
 
     /* now that we have joined the data plane group, join the
-     control/template plane group to signal exporters that
-     we need the templates for this group. */
+     * control/template plane group to signal exporters that
+     * we need the templates for this group. */
 
     for (i = 0; i < spread->num_groups; ++i)
     {
@@ -1510,7 +1487,6 @@ static gboolean fbCollectorSpreadRead(
         }
 
         if (ret < 0) {
-
             if (ret == GROUPS_TOO_SHORT) {
                 g_free(spread->recv_groups);
                 spread->recv_max_groups = -spread->recv_num_groups;
@@ -1518,8 +1494,8 @@ static gboolean fbCollectorSpreadRead(
                                               spread->recv_max_groups );
             } else if (ret == BUFFER_TOO_SHORT) {
                 *msglen = -endian_mismatch;
-                g_set_error( err, FB_ERROR_DOMAIN, FB_ERROR_EOM,
-                             "msglen too small (%zd required)", *msglen );
+                g_set_error(err, FB_ERROR_DOMAIN, FB_ERROR_EOM,
+                            "msglen too small (%zd required)", *msglen);
                 return FALSE;
             } else if ((ret == CONNECTION_CLOSED) || (ret == ILLEGAL_SESSION))
             {
@@ -1881,20 +1857,3 @@ void fbCollectorSetUDPMultiSession(
 {
     collector->multi_session = multi_session;
 }
-
-/**
- * netflow v9 spec says:
- * NetFlow Collectors SHOULD use the combination of the source IP
- * address and the Source ID field to separate different export
- * streams originating from the same Exporter.
- *
- * however, some routers make this difficult, so turn this flag
- * on to prevent fixbuf from clearing out the ports before comparing
- * sockaddr structs.
- */
-void fbCollectorManageUDPStreamByPort(
-    fbCollector_t *collector,
-    gboolean       manage_port)
-{
-    collector->stream_by_port = manage_port;
-}
