@@ -6,56 +6,37 @@
  * IPFIX Exporting Process single transport session implementation
  *
  ** ------------------------------------------------------------------------
- ** Copyright (C) 2006-2015 Carnegie Mellon University. All Rights Reserved.
+ ** Copyright (C) 2006-2018 Carnegie Mellon University. All Rights Reserved.
  ** ------------------------------------------------------------------------
  ** Authors: Brian Trammell
  ** ------------------------------------------------------------------------
- ** @OPENSOURCE_HEADER_START@
- ** Use of the libfixbuf system and related source code is subject to the terms
- ** of the following licenses:
+ ** @OPENSOURCE_LICENSE_START@
+ ** libfixbuf 2.0
  **
- ** GNU Lesser GPL (LGPL) Rights pursuant to Version 2.1, February 1999
- ** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+ ** Copyright 2018 Carnegie Mellon University. All Rights Reserved.
  **
- ** NO WARRANTY
+ ** NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE
+ ** ENGINEERING INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS"
+ ** BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY KIND,
+ ** EITHER EXPRESSED OR IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT
+ ** LIMITED TO, WARRANTY OF FITNESS FOR PURPOSE OR MERCHANTABILITY,
+ ** EXCLUSIVITY, OR RESULTS OBTAINED FROM USE OF THE
+ ** MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT MAKE ANY WARRANTY OF
+ ** ANY KIND WITH RESPECT TO FREEDOM FROM PATENT, TRADEMARK, OR
+ ** COPYRIGHT INFRINGEMENT.
  **
- ** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
- ** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
- ** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
- ** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
- ** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
- ** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
- ** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
- ** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
- ** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
- ** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
- ** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
- ** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
- ** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
- ** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
- ** DELIVERABLES UNDER THIS LICENSE.
+ ** Released under a GNU-Lesser GPL 3.0-style license, please see
+ ** LICENSE.txt or contact permission@sei.cmu.edu for full terms.
  **
- ** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
- ** Mellon University, its trustees, officers, employees, and agents from
- ** all claims or demands made against them (and any related losses,
- ** expenses, or attorney's fees) arising out of, or relating to Licensee's
- ** and/or its sub licensees' negligent use or willful misuse of or
- ** negligent conduct or willful misconduct regarding the Software,
- ** facilities, or other rights or assistance granted by Carnegie Mellon
- ** University under this License, including, but not limited to, any
- ** claims of product liability, personal injury, death, damage to
- ** property, or violation of any laws or regulations.
+ ** [DISTRIBUTION STATEMENT A] This material has been approved for
+ ** public release and unlimited distribution.  Please see Copyright
+ ** notice for non-US Government use and distribution.
  **
- ** Carnegie Mellon University Software Engineering Institute authored
- ** documents are sponsored by the U.S. Department of Defense under
- ** Contract FA8721-05-C-0003. Carnegie Mellon University retains
- ** copyrights in all material produced under this contract. The U.S.
- ** Government retains a non-exclusive, royalty-free license to publish or
- ** reproduce these documents, or allow others to do so, for U.S.
- ** Government purposes only pursuant to the copyright license under the
- ** contract clause at 252.227.7013.
+ ** Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent
+ ** and Trademark Office by Carnegie Mellon University.
  **
- ** @OPENSOURCE_HEADER_END@
+ ** DM18-0325
+ ** @OPENSOURCE_LICENSE_END@
  ** ------------------------------------------------------------------------
  *
  */
@@ -64,7 +45,6 @@
 /*#define _GNU_SOURCE*/
 #include <fixbuf/private.h>
 
-#ident "$Id$"
 
 /**
  * If set in exporter SCTP mode, use simple automatic stream selection as
@@ -264,6 +244,7 @@ static gboolean fbExporterOpenBuffer(
     fbExporter_t                *exporter,
     GError                      **err)
 {
+    (void)err;
     /* set active flag */
     exporter->active = TRUE;
 
@@ -289,9 +270,8 @@ static gboolean fbExporterWriteBuffer(
     size_t                   msglen,
     GError                   **err)
 {
-
+    (void)err;
     memcpy(exporter->stream.buffer, msgbase, msglen);
-
     exporter->msg_len = msglen;
 
     return TRUE;
@@ -320,32 +300,6 @@ fbExporter_t *fbExporterAllocBuffer(
     return exporter;
 }
 
-/**
- *fbExporterSetFilePath
- *
- *
- * @param exporter
- * @param path
- *
- */
-void         fbExporterSetFilePath(
-    fbExporter_t    *exporter,
-    char            *path)
-{
-    /* Only valid if this is a file path based exporter */
-    g_assert(exporter->exopen == fbExporterOpenFile);
-
-    /* Force exporter closed if it's active */
-    if (exporter->active) exporter->exclose(exporter);
-
-    /* Free old file path if necessary */
-    if (exporter->spec.path) {
-        g_free(exporter->spec.path);
-    }
-
-    exporter->spec.path = g_strdup(path);
-}
-
 /**
  *fbExporterAllocFP
  *
@@ -377,26 +331,6 @@ fbExporter_t    *fbExporterAllocFP(
     return exporter;
 }
 
-/**
- *fbExporterSetFP
- *
- *
- * @param exporter
- * @param fp
- *
- */
-void         fbExporterSetFP(
-    fbExporter_t    *exporter,
-    FILE            *fp)
-{
-    /* Only valid if this is a file path based exporter */
-    g_assert(!exporter->exopen);
-    g_assert(exporter->exwrite == fbExporterWriteFile);
-
-    /* Change file pointer */
-    exporter->stream.fp = fp;
-}
-
 /**
  *fbExporterIgnoreSigpipe
  *
@@ -1126,7 +1060,6 @@ static void * fbExporterSpreadReceiver(
         /** Send Relevant Templates to New Member only. */
         /** memb_info.changed_member is private group name */
         /** sender is group they are subscribing to */
-
         fbSessionSetPrivateGroup(spread->session,
                                  sender, memb_info.changed_member);
 
@@ -1229,14 +1162,14 @@ static gboolean fbExporterSpreadWrite(
 
     spread = exporter->spec.spread;
 
-    if (spread->num_groups == 1) {
-        ret = SP_multicast(spread->mbox, RELIABLE_MESS,
-                           spread->groups[0].name,
-                           0, msglen, (const char *)msgbase);
-    } else if (spread->num_groups_to_send == 1) {
+    if (spread->num_groups_to_send == 1) {
         ret = SP_multicast(spread->mbox, RELIABLE_MESS,
                            spread->groups_to_send[0].name,
                            0, msglen, (const char *)msgbase);
+    } else if (spread->num_groups == 1) {
+        ret = SP_multicast(spread->mbox, RELIABLE_MESS,
+                           spread->groups[0].name,
+                           0, msglen, (const char *)msgbase);
     } else if (spread->num_groups_to_send > 1) {
         ret = SP_multigroup_multicast(spread->mbox, RELIABLE_MESS,
                                       spread->num_groups_to_send,
@@ -1402,6 +1335,7 @@ void fbExporterAutoStream(
     exporter->sctp_mode |= FB_F_SCTP_AUTOSTREAM;
 }
 
+#if 0
 /**
  *fbExporterSetPRTTL
  *
@@ -1422,6 +1356,7 @@ void fbExporterSetPRTTL(
         exporter->sctp_pr_param = 0;
     }
 }
+#endif  /* 0 */
 
 /**
  *fbExportMessage
