@@ -4,56 +4,37 @@
  * IPFIX Collecting Process connection listener implementation
  *
  * ------------------------------------------------------------------------
- * Copyright (C) 2006-2015 Carnegie Mellon University. All Rights Reserved.
+ * Copyright (C) 2006-2018 Carnegie Mellon University. All Rights Reserved.
  * ------------------------------------------------------------------------
  * Authors: Brian Trammell
  * ------------------------------------------------------------------------
- * @OPENSOURCE_HEADER_START@
- * Use of the libfixbuf system and related source code is subject to the terms
- * of the following licenses:
+ * @OPENSOURCE_LICENSE_START@
+ * libfixbuf 2.0
  *
- * GNU Lesser GPL (LGPL) Rights pursuant to Version 2.1, February 1999
- * Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
+ * Copyright 2018 Carnegie Mellon University. All Rights Reserved.
  *
- * NO WARRANTY
+ * NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE
+ * ENGINEERING INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS"
+ * BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY KIND,
+ * EITHER EXPRESSED OR IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT
+ * LIMITED TO, WARRANTY OF FITNESS FOR PURPOSE OR MERCHANTABILITY,
+ * EXCLUSIVITY, OR RESULTS OBTAINED FROM USE OF THE
+ * MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT MAKE ANY WARRANTY OF
+ * ANY KIND WITH RESPECT TO FREEDOM FROM PATENT, TRADEMARK, OR
+ * COPYRIGHT INFRINGEMENT.
  *
- * ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
- * PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
- * PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
- * "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
- * KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
- * LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
- * MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
- * OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
- * SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
- * TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
- * WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
- * LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
- * CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
- * CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
- * DELIVERABLES UNDER THIS LICENSE.
+ * Released under a GNU-Lesser GPL 3.0-style license, please see
+ * LICENSE.txt or contact permission@sei.cmu.edu for full terms.
  *
- * Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
- * Mellon University, its trustees, officers, employees, and agents from
- * all claims or demands made against them (and any related losses,
- * expenses, or attorney's fees) arising out of, or relating to Licensee's
- * and/or its sub licensees' negligent use or willful misuse of or
- * negligent conduct or willful misconduct regarding the Software,
- * facilities, or other rights or assistance granted by Carnegie Mellon
- * University under this License, including, but not limited to, any
- * claims of product liability, personal injury, death, damage to
- * property, or violation of any laws or regulations.
+ * [DISTRIBUTION STATEMENT A] This material has been approved for
+ * public release and unlimited distribution.  Please see Copyright
+ * notice for non-US Government use and distribution.
  *
- * Carnegie Mellon University Software Engineering Institute authored
- * documents are sponsored by the U.S. Department of Defense under
- * Contract FA8721-05-C-0003. Carnegie Mellon University retains
- * copyrights in all material produced under this contract. The U.S.
- * Government retains a non-exclusive, royalty-free license to publish or
- * reproduce these documents, or allow others to do so, for U.S.
- * Government purposes only pursuant to the copyright license under the
- * contract clause at 252.227.7013.
+ * Carnegie Mellon(R) and CERT(R) are registered in the U.S. Patent
+ * and Trademark Office by Carnegie Mellon University.
  *
- * @OPENSOURCE_HEADER_END@
+ * DM18-0325
+ * @OPENSOURCE_LICENSE_END@
  * ------------------------------------------------------------------------
  */
 
@@ -61,7 +42,6 @@
 #include <fixbuf/private.h>
 #include <poll.h>
 
-#ident "$Id$"
 
 
 /**
@@ -217,6 +197,7 @@ static gboolean fbListenerInitSocket(
 {
     int                         pfd[2];
     int                         i = 0;
+    int                         count = 0;
     struct pollfd               *cpfd = NULL;
     struct addrinfo             *ai = NULL;
     struct addrinfo             *current = NULL;
@@ -297,10 +278,12 @@ static gboolean fbListenerInitSocket(
             }
         }
         i++;
+        /* Socket successfully bound for listening */
+        count++;
     } while ((ai = ai->ai_next));
 
     /* check for no listenable socket */
-    if (i == 2) {
+    if (!count) {
         fbListenerTeardownSocket(listener);
         g_set_error(err, FB_ERROR_DOMAIN, FB_ERROR_CONN,
                     "couldn't create socket listening to %s:%s: %s",
@@ -1161,7 +1144,7 @@ int fbListenerGroupDeleteListener(
     return 1;
 }
 
-fbListenerGroupResult_t *fbListenerNewResult(
+static fbListenerGroupResult_t *fbListenerNewResult(
     fbListenerGroupResult_t **resultList,
     fbListener_t            *listener)
 {
